package org.netbeans.modules.cnd.dwarfdump.section;

import java.io.IOException;
import java.util.HashMap;

import org.netbeans.modules.cnd.dwarfdump.CompilationUnit;
import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfExpression;
import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfExpressions;
import org.netbeans.modules.cnd.dwarfdump.dwarf.DwarfLocationList;
import org.netbeans.modules.cnd.dwarfdump.reader.DwarfReader;

public class DwarfDebugLocSection extends ElfSection {
    HashMap<Long, DwarfLocationList> locationLists = new HashMap<Long, DwarfLocationList>();
    CompilationUnit unit;
    static final long largestAddress = -1;

    public DwarfDebugLocSection(DwarfReader reader, int sectionIdx) {
        super(reader, sectionIdx);
    }
    
    public DwarfLocationList getLocationList(long defaultBaseAddress, long offset) {
        Long lOffset = Long.valueOf(offset);
        DwarfLocationList locationList = locationLists.get(lOffset);
        
        if (locationList == null) {
            try {
            	locationList = readLocationList(defaultBaseAddress, offset);
            	locationLists.put(lOffset, locationList);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }
        
        return locationList;
    }
    
    private DwarfLocationList readLocationList(long defaultBaseAddress, long offset) throws IOException {
        long currPos = reader.getFilePointer();
        
        reader.seek(header.getSectionOffset() + offset);
        
        DwarfLocationList locationList = new DwarfLocationList(offset);
        
        long baseAddress = defaultBaseAddress;
        
        boolean done = false;
        do {
	        // Beginning relative address offset
	        long begin = reader.readAddress();
	        
	        // Ending relative address offset
	        long end = reader.readAddress();
	        
	        if (begin == 0 && end == 0) {
	        	// End of location list
	        	done = true;
	        } else if (begin == largestAddress) {
	        	// Base address selection entry
	        	baseAddress = end;
	        } else {
		        /* Location expression describing the location of the object over the
		         * range */
	        	DwarfExpression location = DwarfExpressions.readExpression(reader);
	        	locationList.addLocation(baseAddress + begin, baseAddress + end, location);
	        }
	    } while (!done);
        
        reader.seek(currPos);
	    
		return locationList;
	}
}
